@@ -20,7 +20,6 @@ import (
 	"github.com/openshift/cluster-monitoring-operator/pkg/client"
 	"github.com/openshift/cluster-monitoring-operator/pkg/manifests"
 	"github.com/pkg/errors"
-	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/klog"
 )
 
@@ -89,13 +88,21 @@ func (t *PrometheusTask) Run() error {
 		return errors.Wrap(err, "creating Prometheus proxy Secret failed")
 	}
 
-	c := t.client.KubernetesInterface()
-	cm, err := c.CoreV1().Secrets(t.client.Namespace()).Get("grafana-datasources", metav1.GetOptions{})
+	gs, err := t.factory.GrafanaDatasources()
 	if err != nil {
-		return errors.Wrap(err, "failed to retrieve Grafana datasources config")
+		return errors.Wrap(err, "initializing Grafana Datasources Secret failed")
 	}
+
+	gs, err = t.client.WaitForSecret(gs)
+	if err != nil {
+		return errors.Wrap(err, "waiting for Grafana Datasources Secret failed")
+	}
+
 	d := &manifests.GrafanaDatasources{}
-	err = json.Unmarshal(cm.Data["prometheus.yaml"], d)
+	err = json.Unmarshal(gs.Data["prometheus.yaml"], d)
+	if err != nil {
+		return errors.Wrap(err, "unmarshalling grafana datasource failed")
+	}
 
 	hs, err := t.factory.PrometheusK8sHtpasswdSecret(d.Datasources[0].BasicAuthPassword)
 	if err != nil {
@@ -263,8 +270,9 @@ func (t *PrometheusTask) Run() error {
 	}
 
 	err = t.client.DeleteHashedSecret(
-		string(s.Labels["monitoring.openshift.io/hash"]),
+		s.GetNamespace(),
 		"prometheus-k8s-grpc-tls",
+		string(s.Labels["monitoring.openshift.io/hash"]),
 	)
 	if err != nil {
 		return errors.Wrap(err, "error creating Prometheus Client GRPC TLS secret")
@@ -276,26 +284,14 @@ func (t *PrometheusTask) Run() error {
 			return errors.Wrap(err, "initializing Prometheus CA bundle ConfigMap failed")
 		}
 
-		trustedCA, err = t.client.CreateIfNotExistConfigMap(trustedCA)
-		if err != nil {
-			return errors.Wrap(err, " creating Promehteus CA bundle ConfigMap failed")
+		cbs := &caBundleSyncer{
+			client:  t.client,
+			factory: t.factory,
+			prefix:  "prometheus",
 		}
-		// In the case when there is no data but the ConfigMap is there, we just continue.
-		// We will catch this on the next loop.
-		trustedCA = t.factory.HashTrustedCA(trustedCA, "prometheus")
-		if trustedCA != nil {
-			err = t.client.CreateOrUpdateConfigMap(trustedCA)
-			if err != nil {
-				return errors.Wrap(err, "reconciling Prometheus CA bundle ConfigMap failed")
-			}
-
-			err = t.client.DeleteHashedConfigMap(
-				string(trustedCA.Labels["monitoring.openshift.io/hash"]),
-				"prometheus",
-			)
-			if err != nil {
-				return errors.Wrap(err, "deleting old Prometheus configmaps failed")
-			}
+		trustedCA, err = cbs.syncTrustedCABundle(trustedCA)
+		if err != nil {
+			return errors.Wrap(err, "syncing Prometheus trusted CA bundle ConfigMap failed")
 		}
 
 		klog.V(4).Info("initializing Prometheus object")
